@@ -22,18 +22,28 @@
  */
 
 struct apparam_field {
-	guint64		filter;
+	/* list and pull attributes */
 	guint16		maxlistcount;
 	guint16		liststartoffset;
+
+	/* pull and vcard attributes */
+	guint64		filter;
 	guint8		format;
+
+	/* list attributes only */
 	guint8		order;
 	guint8		searchattrib;
 	guint8		*searchval;
 };
 
-int phonebook_pullphonebook(obex_t *obex, obex_object_t *obj,
-				struct apparam_field params);
-int phonebook_pullvcardlisting(obex_t *obex, obex_object_t *obj,
-				struct apparam_field params);
-int phonebook_pullvcardentry(obex_t *obex, obex_object_t *obj,
-				struct apparam_field params);
+typedef void (*phonebook_cb) (const gchar *buffer, size_t bufsize,
+		gint vcards, gint missed, gpointer user_data);
+
+int phonebook_init(void);
+void phonebook_exit(void);
+
+int phonebook_set_folder(const gchar *current_folder,
+		const gchar *new_folder, guint8 flags);
+
+int phonebook_pull(const gchar *name, const struct apparam_field *params,
+		phonebook_cb cb, gpointer user_data);
